@@ -34,33 +34,37 @@
 /* copyright --> */
 #include "DHTAnnouncePeerReplyMessage.h"
 #include "DHTNode.h"
-#include "bencode.h"
+#include "DHTMessageCallback.h"
 
 namespace aria2 {
 
 const std::string DHTAnnouncePeerReplyMessage::ANNOUNCE_PEER("announce_peer");
 
-DHTAnnouncePeerReplyMessage::DHTAnnouncePeerReplyMessage(const SharedHandle<DHTNode>& localNode,
-                                                         const SharedHandle<DHTNode>& remoteNode,
-                                                         const std::string& transactionID):
+DHTAnnouncePeerReplyMessage::DHTAnnouncePeerReplyMessage
+(const SharedHandle<DHTNode>& localNode,
+ const SharedHandle<DHTNode>& remoteNode,
+ const std::string& transactionID):
   DHTResponseMessage(localNode, remoteNode, transactionID) {}
 
 DHTAnnouncePeerReplyMessage::~DHTAnnouncePeerReplyMessage() {}
 
 void DHTAnnouncePeerReplyMessage::doReceivedAction() {}
 
-BDE DHTAnnouncePeerReplyMessage::getResponse()
+SharedHandle<Dict> DHTAnnouncePeerReplyMessage::getResponse()
 {
-  BDE rDict = BDE::dict();
-  rDict[DHTMessage::ID] = BDE(_localNode->getID(), DHT_ID_LENGTH);
+  SharedHandle<Dict> rDict = Dict::g();
+  rDict->put(DHTMessage::ID, String::g(getLocalNode()->getID(), DHT_ID_LENGTH));
   return rDict;
 }
 
-std::string DHTAnnouncePeerReplyMessage::getMessageType() const
+const std::string& DHTAnnouncePeerReplyMessage::getMessageType() const
 {
   return ANNOUNCE_PEER;
 }
 
-void DHTAnnouncePeerReplyMessage::validate() const {}
+void DHTAnnouncePeerReplyMessage::accept(DHTMessageCallback* callback)
+{
+  callback->visit(this);
+}
 
 } // namespace aria2
