@@ -32,22 +32,19 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_FEEDBACK_URI_SELECTOR_H_
-#define _D_FEEDBACK_URI_SELECTOR_H_
+#ifndef D_FEEDBACK_URI_SELECTOR_H
+#define D_FEEDBACK_URI_SELECTOR_H
 #include "URISelector.h"
 #include "SharedHandle.h"
 
 namespace aria2 {
 
 class ServerStatMan;
-class Logger;
 
 class FeedbackURISelector:public URISelector {
 private:
   SharedHandle<ServerStatMan> serverStatMan_;
 
-  Logger* logger_;
-
   std::string selectRarer
   (const std::deque<std::string>& uris,
    const std::vector<std::pair<size_t, std::string> >& usedHosts);
@@ -68,4 +65,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_FEEDBACK_URI_SELECTOR_H_
+#endif // D_FEEDBACK_URI_SELECTOR_H
