@@ -51,9 +51,9 @@
 #include "a2io.h"
 #include "help_tags.h"
 #include "File.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "OptionHandlerException.h"
-#include "DownloadResultCode.h"
+#include "error_code.h"
 #include "SimpleRandomizer.h"
 #include "bittorrent_helper.h"
 #ifndef HAVE_DAEMON
@@ -103,7 +103,7 @@ void option_processing(Option& op, std::vector<std::string>& uris,
 
       if(op.defined("version")) {
         showVersion();
-        exit(downloadresultcode::FINISHED);
+        exit(error_code::FINISHED);
       }
       if(op.defined("help")) {
         std::string keyword;
@@ -120,7 +120,7 @@ void option_processing(Option& op, std::vector<std::string>& uris,
           }
         }
         showUsage(keyword, oparser);
-        exit(downloadresultcode::FINISHED);
+        exit(error_code::FINISHED);
       }
     }
 
@@ -140,23 +140,22 @@ void option_processing(Option& op, std::vector<std::string>& uris,
           std::cerr << "Parse error in " << cfname << "\n"
                     << e.stackTrace() << std::endl;
           SharedHandle<OptionHandler> h = oparser.findByName(e.getOptionName());
-          if(!h.isNull()) {
+          if(h) {
             std::cerr << "Usage:" << "\n"
                       << oparser.findByName(e.getOptionName())->getDescription()
                       << std::endl;
           }
-          exit(downloadresultcode::UNKNOWN_ERROR);
+          exit(e.getErrorCode());
         } catch(Exception& e) {
           std::cerr << "Parse error in " << cfname << "\n"
                     << e.stackTrace() << std::endl;
-          exit(downloadresultcode::UNKNOWN_ERROR);
+          exit(e.getErrorCode());
         }
       } else if(!ucfname.empty()) {
-        std::cerr << StringFormat("Configuration file %s is not found.",
-                                  cfname.c_str())
+        std::cerr << fmt("Configuration file %s is not found.", cfname.c_str())
                   << "\n";
         showUsage(TAG_HELP, oparser);
-        exit(downloadresultcode::UNKNOWN_ERROR);
+        exit(error_code::UNKNOWN_ERROR);
       }
     }
     // Override configuration with environment variables.
@@ -172,15 +171,18 @@ void option_processing(Option& op, std::vector<std::string>& uris,
     // finaly let's parse and store command-iine options.
     oparser.parse(op, cmdstream);
   } catch(OptionHandlerException& e) {
-    std::cerr << e.stackTrace() << "\n"
-              << "Usage:" << "\n"
-              << oparser.findByName(e.getOptionName())
-              << std::endl;
-    exit(downloadresultcode::UNKNOWN_ERROR);
+    std::cerr << e.stackTrace() << "\n";
+    SharedHandle<OptionHandler> h = oparser.findByName(e.getOptionName());
+    if(h) {
+      std::cerr << "Usage:" << "\n"
+                << *h
+                << std::endl;
+    }
+    exit(e.getErrorCode());
   } catch(Exception& e) {
     std::cerr << e.stackTrace() << std::endl;
     showUsage(TAG_HELP, oparser);
-    exit(downloadresultcode::UNKNOWN_ERROR);
+    exit(e.getErrorCode());
   }
   if(
 #ifdef ENABLE_XML_RPC
@@ -196,13 +198,13 @@ void option_processing(Option& op, std::vector<std::string>& uris,
     if(uris.empty()) {
       std::cerr << MSG_URI_REQUIRED << std::endl;
       showUsage(TAG_HELP, oparser);
-      exit(downloadresultcode::UNKNOWN_ERROR);
+      exit(error_code::UNKNOWN_ERROR);
     }
   }
   if(op.getAsBool(PREF_DAEMON)) {
     if(daemon(0, 0) < 0) {
       perror(MSG_DAEMON_FAILED);
-      exit(downloadresultcode::UNKNOWN_ERROR);
+      exit(error_code::UNKNOWN_ERROR);
     }
   }
 }
